Delete

Struct Delete 

pub struct Delete<T> {
    pub table: Table<T>,
    pub query: Query,
    /* private fields */
}
A typed delete statement under construction.

Fields

table: Table<T>

Delete target table.

query: Query

Shared query state used for filters, CTEs, and parameters.

Implementations

Source

impl<T> Delete<T>

pub fn with<C>(self, ctes: C) -> Delete<T>
where C: IntoCtes,

Attaches a common table expression to the delete.

pub fn with_recursive<C>(self, ctes: C) -> Delete<T>
where C: IntoCtes,

Attaches a recursive common table expression to the delete.

pub fn filter<F>(self, clause: F) -> Delete<T>
where F: LowerFilter,

Adds a where predicate combined with and.

pub fn or_filter<F>(self, clause: F) -> Delete<T>
where F: LowerFilter,

Adds a where predicate combined with or.

pub fn into_compiled<D>(self) -> TypedCompiled<T>
where D: HasDialect,

Compiles the delete into the typed representation used by executors.

pub fn to_debug_sql<D>(&mut self) -> String
where D: HasDialect,

Emits SQL with appended debug parameter output.

pub fn to_sql<D>(&mut self) -> String
where D: HasDialect,

Emits SQL for the requested dialect.

Source

impl<T> Delete<T>

pub fn force(self) -> Delete<T>

Source

impl<T> Delete<T>

pub async fn execute<E>(self, exec: E) -> Result<ExecResult, Error>
where E: Executor,