Query

Struct Query 

pub struct Query { /* private fields */ }
Untyped query state used while shaping SQL structure.

This is the flexible form you use while adding joins, changing projections, or otherwise building a statement whose final row shape is not settled yet.

Implementations

Source

impl Query

pub fn delete_query(self) -> Delete<()>

pub async fn delete<E>(self, exec: E) -> Result<ExecResult, Error>
where E: Executor,

Source

impl Query

pub fn select<S>(self, s: S) -> Query
where S: LowerProject,

Replaces the current projection list.

pub fn reset_select(&mut self)

Clears the current projection list.

pub fn left_join<J>(self, join: J) -> Query
where J: LowerJoin,

Adds a left join to the current from clause.

pub fn right_join<J>(self, join: J) -> Query
where J: LowerJoin,

Adds a right join to the current from clause.

pub fn inner_join<J>(self, join: J) -> Query
where J: LowerJoin,

Adds an inner join to the current from clause.

pub fn having<E>(self, e: E) -> Query
where E: LowerHaving,

Adds a having predicate combined with and.

pub fn or_having<E>(self, e: E) -> Query
where E: LowerHaving,

Adds a having predicate combined with or.

pub fn filter<E>(self, e: E) -> Query
where E: LowerFilter,

Adds a where predicate combined with and.

pub fn or_filter<E>(self, e: E) -> Query
where E: LowerFilter,

Adds a where predicate combined with or.

pub fn from<T>(table: T) -> Query
where T: LowerFrom,

Starts a query from the given source.

pub fn union(self, other: impl Into<Query>) -> Query

Combines this query with another one using union.

pub fn union_all(self, other: impl Into<Query>) -> Query

Combines this query with another one using union all.

pub fn group_by<T>(self, by: T) -> Query
where T: LowerGroupBy,

Appends grouping expressions to group by.

pub fn order_by<T>(self, by: T) -> Query
where T: LowerOrderBy,

Appends ordering expressions to order by.

pub fn order_by_random(self) -> Query

Appends a random ordering expression.

pub fn limit<E>(self, e: E) -> Query
where E: LowerCompatible<BigInt>,

Replaces any existing limit clause.

pub fn reset_limit(&mut self)

Clears the current limit clause.

pub fn offset<E>(self, e: E) -> Query
where E: LowerCompatible<BigInt>,

Replaces any existing offset clause.

pub fn reset_offset(&mut self)

Clears the current offset clause.

pub fn lock_for_update(self) -> LockedQuery

Adds for update.

pub fn shared_lock(self) -> LockedQuery

Adds the dialect’s shared-row lock clause.

pub fn with<C>(self, ctes: C) -> Query
where C: IntoCtes,

Attaches a common table expression.

pub fn with_recursive<C>(self, ctes: C) -> Query
where C: IntoCtes,

Attaches a recursive common table expression.

pub fn scalar<T>(self) -> Scalar<T>
where T: TypeMeta,

Treats the query as a scalar subquery of the requested type.

pub fn distinct(self) -> Query

Emits select distinct.

pub fn not_distinct(self) -> Query

Clears the distinct flag.

pub fn typed<M>(self) -> QueryOf<M>
where M: FromRow,

Attaches a row type once the result shape is known.

pub fn typed_locked<M>(self) -> LockedQueryOf<M>
where M: FromRow,

pub fn to_sql<D>(&mut self) -> String
where D: HasDialect,

Emits SQL for the requested dialect.

pub fn into_compiled<D>(self) -> Compiled
where D: HasDialect,

Compiles the query into an untyped executable payload.

pub fn to_debug_sql<D>(&mut self) -> String
where D: HasDialect,

Emits SQL followed by a debug view of the current parameters.

Source

impl Query

pub async fn fetch<'e, E>( self, exec: &'e mut E, ) -> Result<<E as Executor>::Rows<'e>, Error>
where E: Executor + ?Sized,

pub async fn all<T>(self, exec: impl Executor) -> Result<Vec<T>, Error>
where T: FromRow,

pub async fn one<T>(self, exec: impl Executor) -> Result<T, Error>
where T: FromRow,

pub async fn optional<T>(self, exec: impl Executor) -> Result<Option<T>, Error>
where T: FromRow,

pub async fn count<E>(self, exec: E) -> Result<i64, Error>
where E: Executor,