SqliteConnectOptions

Struct SqliteConnectOptions 

pub struct SqliteConnectOptions { /* private fields */ }
sqlite connection settings.

Implementations

Source

impl SqliteConnectOptions

pub fn new() -> SqliteConnectOptions

Starts with an on-disk sqlite database created when missing.

pub fn path(self, value: impl Into<PathBuf>) -> SqliteConnectOptions

Sets the database path.

pub fn in_memory(self) -> SqliteConnectOptions

Uses an in-memory database.

This clears any path already set on the options.

pub fn read_only(self, value: bool) -> SqliteConnectOptions

Sets whether sqlite opens the database as read-only.

pub fn create_if_missing(self, value: bool) -> SqliteConnectOptions

Sets whether sqlite creates the database file when missing.

pub fn busy_timeout(self, value: Duration) -> SqliteConnectOptions

Sets sqlite’s busy timeout.