pub struct Delete<T> {
pub table: Table<T>,
pub query: Query,
/* private fields */
}Expand description
A typed delete statement under construction.
Fields
table: Table<T>Delete target table.
query: QueryShared query state used for filters, CTEs, and parameters.
Implementations
Sourceimpl<T> Delete<T>
impl<T> Delete<T>
Sourcepub fn with<C>(self, ctes: C) -> Delete<T>where
C: IntoCtes,
pub fn with<C>(self, ctes: C) -> Delete<T>where
C: IntoCtes,
Attaches a common table expression to the delete.
Sourcepub fn with_recursive<C>(self, ctes: C) -> Delete<T>where
C: IntoCtes,
pub fn with_recursive<C>(self, ctes: C) -> Delete<T>where
C: IntoCtes,
Attaches a recursive common table expression to the delete.
Sourcepub fn filter<F>(self, clause: F) -> Delete<T>where
F: LowerFilter,
pub fn filter<F>(self, clause: F) -> Delete<T>where
F: LowerFilter,
Adds a where predicate combined with and.
Sourcepub fn or_filter<F>(self, clause: F) -> Delete<T>where
F: LowerFilter,
pub fn or_filter<F>(self, clause: F) -> Delete<T>where
F: LowerFilter,
Adds a where predicate combined with or.
Sourcepub fn into_compiled<D>(self) -> TypedCompiled<T>where
D: HasDialect,
pub fn into_compiled<D>(self) -> TypedCompiled<T>where
D: HasDialect,
Compiles the delete into the typed representation used by executors.
Sourcepub fn to_debug_sql<D>(&mut self) -> Stringwhere
D: HasDialect,
pub fn to_debug_sql<D>(&mut self) -> Stringwhere
D: HasDialect,
Emits SQL with appended debug parameter output.
Sourcepub fn to_sql<D>(&mut self) -> Stringwhere
D: HasDialect,
pub fn to_sql<D>(&mut self) -> Stringwhere
D: HasDialect,
Emits SQL for the requested dialect.