pub trait FromColumnRef<'r>: Sized {
// Required method
fn from_column_ref(row: &'r RowRef<'r>, index: usize) -> Result<Self, Error>;
}Expand description
Decodes one column directly from a borrowed row.
This is the trait behind RowRef::get. Most types do not need to
implement it manually because many implementations can go through
Decode.
Implementors may borrow from row, so the returned value must not outlive
'r.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.